@@ -12,6 +12,35 @@ from subprocess import PIPE, Popen
 from threading  import Thread
 import tempfile
 
+
+from multiprocessing import Pool
+from functools import partial
+
+
+def _pickle_method(method):
+    func_name = method.im_func.__name__
+    obj = method.im_self
+    cls = method.im_class
+    if func_name.startswith('__') and not func_name.endswith('__'): #deal with mangled names
+        cls_name = cls.__name__.lstrip('_')
+        func_name = '_' + cls_name + func_name
+    return _unpickle_method, (func_name, obj, cls)
+
+
+def _unpickle_method(func_name, obj, cls):
+    for cls in cls.__mro__:
+        try:
+            func = cls.__dict__[func_name]
+        except KeyError:
+            pass
+        else:
+            break
+    return func.__get__(obj, cls)
+
+import copyreg
+import types
+copyreg.pickle(types.MethodType, _pickle_method, _unpickle_method)
+
 try:
     from queue import Queue, Empty
 except ImportError:
@@ -439,7 +468,20 @@ class Eniam():
     def ne_str(self):
         return "" if self.ne is None else self.ne
 
-    def dom(self, input_text, silent=True):
+    def dom(self, input, silent=True):
+        if isinstance(input, list):
+            pool = Pool()
+            opts = {
+                'silent': silent,
+            }
+            return pool.map(self._exec_dom, map(lambda sentence: [sentence, opts], input))
+        else:
+            return self._exec_dom(input, silent)
+
+    def _exec_dom_opt(self, args):
+        return self._exec_dom(args[0], **(args[1]))
+
+    def _exec_dom(self, input_text, silent=True):
         p = run_domparser(["--no-sem", "--no-def-cat"], PIPE, PIPE, self.lexicon_content, self.valence_content, self.mwe, self.ne)
         q_out = Queue()
         q_err = Queue()
