@@ -17,7 +17,7 @@ SUPPORTED_VALUES = {
         "bedzie", "praet", "winien", "impt", "imps",
         "pred", "aglt", "inf", "pcon", "pant", "qub",
         "comp", "conj", "interj", "sinterj", "burk", "interp",
-        "unk", "apron"
+        "unk", "apron", "part",
     ],
     "number": [ "sg", "pl" ],
     "case": [
@@ -88,6 +88,9 @@ def rule(
     nsyn=None,
     nsem=None
 ):
+    if pos is None:
+        raise Exception("Pos parameter is required for a rule definition.")
+
     for key in SUPPORTED_VALUES:
         if key in locals():
             val = getstrval(locals()[key])
@@ -113,31 +116,31 @@ class gram():
         return self.value
 
     def __add__(self, other):
-        return gram(f"{self.value}+{other.rule()}")
+        return gram(f"{self.value}+{getstrval(other)}")
 
     def __mul__(self, other):
-        return gram(f"{self.value}*{other.rule()}")
+        return gram(f"{self.value}*{getstrval(other)}")
 
     def __gt__(self, other):
-        return gram(f"({self.value})/({other.rule()})")
+        return gram(f"({self.value})/({getstrval(other)})")
 
     def __floordiv__(self, other):
-        return gram(f"({self.value})/({other.rule()})")
+        return gram(f"({self.value})/({getstrval(other)})")
 
     def __lt__(self, other):
-        return gram(f"({self.value})\\({other.rule()})")
+        return gram(f"({self.value})\\({getstrval(other)})")
 
     def __or__(self, other):
         if not self.value.startswith("|"):
-            return gram(f"|({self.value}), |({other.rule()})")
+            return gram(f"|({self.value}), |({getstrval(other)})")
         else:
-            return gram(f"{self.value}, |({other.rule()})")
+            return gram(f"{self.value}, |({getstrval(other)})")
 
     def __mod__(self, other):
-        return gram(f"{self.value}\\?({other.rule()})")
+        return gram(f"{self.value}\\?({getstrval(other)})")
 
     def __getitem__(self, key):
-        rule = key.rule()
+        rule = getstrval(key)
         case_content = ""
         if not rule.startswith("|"):
             case_content = f"|{rule}"
@@ -153,12 +156,14 @@ def quant(gr, **kwargs):
         val_str = ""
         val = kwargs[key]
         if isinstance(val, list):
-            val_str = "&".join(map(lambda x: x.rule(), val))
+            val_str = "&".join(map(lambda x: getstrval(x), val))
         else:
-            val_str = val.rule()
+            val_str = getstrval(val)
         quant_conds.append(f"{key}={val_str}")
-    return "QUANT[" + ",".join(quant_conds) + "] " + gr.rule()
+    return "QUANT[" + ",".join(quant_conds) + "] " + getstrval(gr)
 
+def optional(gr):
+    return gram('?'+getstrval(gr))
 
 infp = gram('infp')
 np = gram('np')
